harvest_candidates

Function harvest_candidates 

pub(crate) fn harvest_candidates(cache: Option<&ProjectCache>) -> Candidates
Build a Candidates set from the project cache: every project item name into items, every schema into schemas, every database into databases, and the unique non-empty cluster names referenced by project objects into clusters. Returns an empty Candidates when cache is None.